Code coverage report for js/widgets/SlugInputWidget.tsx

# All files / js/widgets SlugInputWidget.tsx

50% Statements 2/4
100% Branches 0/0
0% Functions 0/2
50% Lines 2/4

Press n or j to go to the next uncovered block, b, p or k for the previous block.

    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    13
    14
    15
    16
    17
    18
    191x

    1x

     import React from "react";
    import { WidgetProps } from "./types";
    import InputWidgetBase from "./InputWidgetBase";

    function postprocessSlug(value: string) {
      return value.replace(/\s+/g, "-");
    }

    export function SlugInputWidget(props: WidgetProps) {
      return (
        <InputWidgetBase
          inputType="text"
          inputAddon={<i className="fa fa-link" />}
          postprocessValue={postprocessSlug}
          {...props}
        />
      );
    }